pub fn initialize<A: Allocate + 'static>(
worker: &mut Worker<A>,
config: &LoggingConfig,
metrics_registry: MetricsRegistry,
worker_config: Rc<ConfigSet>,
workers_per_process: usize,
) -> LoggingTracesExpand description
Initialize logging dataflows.
Returns a logger for compute events, and for each LogVariant a trace bundle usable for
retrieving logged records as well as the index of the exporting dataflow.