serve_unified

Function serve_unified 

pub async fn serve_unified(
    timely_config: TimelyConfig,
    role: ComputeRuntimeRole,
    metrics_registry: &MetricsRegistry,
    persist_clients: Arc<PersistClientCache>,
    txns_ctx: TxnsContext,
    tracing_handle: Arc<TracingHandle>,
    context: ComputeInstanceContext,
    now: NowFn,
    storage_connection_context: ConnectionContext,
    storage_instance_context: StorageInstanceContext,
) -> Result<(impl Fn() -> Box<dyn ComputeClient> + use<>, impl Fn() -> Box<dyn StorageClient> + use<>), Error>
Initiates a timely dataflow computation that processes compute commands and additionally hosts storage objects, processing storage commands received over a separate client connection.

Returns client builders for both the compute and the storage side.