pub(super) struct ChannelLogging(UnboundedSender<LoggingEvent>);Expand description
Channel-based logging for corrections on a Tokio task. Send-safe.
Sends logging events to the Timely thread, where they are applied to the real Logging
instance. This allows corrections on the Tokio task to participate in introspection logging
without holding Rc<RefCell<..>>.
Tuple Fields
0: UnboundedSender<LoggingEvent>Implementations
Sourceimpl ChannelLogging
impl ChannelLogging
pub fn new(tx: UnboundedSender<LoggingEvent>) -> Self
pub fn chain_created(&self, updates: usize)
pub fn chain_dropped(&self, updates: usize)
pub fn report_size_diff(&self, diff: isize)
pub fn report_capacity_diff(&self, diff: isize)
pub fn report_allocations_diff(&self, diff: isize)