render

Function render 

pub fn render<'s>(
    sink_id: GlobalId,
    persist_api: PersistApi,
    as_of: Antichain<Timestamp>,
    desired: OkErr<StreamVec<'s, Timestamp, (Row, Timestamp, Diff)>, StreamVec<'s, Timestamp, (DataflowError, Timestamp, Diff)>>,
    persist: OkErr<StreamVec<'s, Timestamp, (Row, Timestamp, Diff)>, StreamVec<'s, Timestamp, (DataflowError, Timestamp, Diff)>>,
    descs: StreamVec<'s, Timestamp, BatchDescription>,
    worker_config: Rc<ConfigSet>,
) -> (StreamVec<'s, Timestamp, (BatchDescription, ProtoBatch)>, PressOnDropButton)
Render the write operator.

The parameters passed in are:

  • sink_id: The GlobalId of the sink export.
  • persist_api: An object providing access to the output persist shard.
  • as_of: The first time for which the sink may produce output.
  • desired: The ok/err streams that should be sinked to persist.
  • persist: The ok/err streams read back from the output persist shard.
  • descs: The stream of batch descriptions produced by the mint operator.