trait StepForward<D, R> {
// Required method
fn step_forward(self, name: &str) -> Self;
}Required Methods
Sourcefn step_forward(self, name: &str) -> Self
fn step_forward(self, name: &str) -> Self
Translates a collection one timestamp “forward” (i.e. T -> T+1 as
defined by TimestampManipulation::step_forward).
This includes:
- The differential timestamps in each data.
- The capabilities paired with that data.
- (As a consequence of the previous) the output frontier is one step forward of the input frontier.
The caller is responsible for ensuring that all data and capabilities given to this operator can be stepped forward without panicking, otherwise the operator will panic at runtime.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.