fn build_update_stream<'scope, T, Tr>(
trace: Arranged<'scope, Tr>,
as_of: Antichain<Timestamp>,
source_relation: usize,
initial_closure: JoinClosure,
) -> (VecCollection<'scope, T, Row, Diff>, VecCollection<'scope, T, DataflowError, Diff>)where
T: RenderTimestamp,
for<'a, 'b> &'a T: PartialEq<Tr::TimeGat<'b>>,
Tr: for<'a> TraceReader<Time = T, Diff = Diff> + Clone + 'static,
for<'a> Tr::Key<'a>: ToDatumIter,
for<'a> Tr::Val<'a>: ToDatumIter,Expand description
Builds the beginning of the update stream of a delta path.
At start-up time only the delta path for the first relation sees updates, since any updates fed to the other delta paths would be discarded anyway due to the tie-breaking logic that avoids double-counting updates happening at the same time on different relations.