async fn apply_command(
corrections: &mut OkErr<Correction<Row>, Correction<DataflowErrorSer>>,
writer: &mut WriteHandle<SourceData, (), Timestamp, StorageDiff>,
cmd: WriteCommand,
resp_tx: &UnboundedSender<WriteResponse>,
)Expand description
Apply a single command to the task state.
desired updates enter corrections as positive contributions and persist updates as
negative contributions, so the buffer contains desired - persist, i.e. the updates that
need to be written to bring the shard in line with desired.